Crate hexxdump

Crate hexxdump 

hexxdump is a configurable tool for generating hex dumps

Modules

config

Structs

Hexxdump
A hex dumper with a given configuration

Constants

DEFAULT
A pre-made Hexxdump with a default configuration

Functions

get_hexdump
Returns the hexdump of bytes as a String, with a default configuration
hexdump
Writes the hex dump of bytes to stdout with a default configuration
hexdump_to
Writes the hexdump of bytes to the given byte sink output with a default configuration